pub struct Scope<N>{ /* private fields */ }Expand description
Scope defining enclosing viewing frustum.
Implements Default and can be created with Scope::default().
Implementations
Sourceimpl<N> Scope<N>
impl<N> Scope<N>
Sourcepub const fn fov(&self) -> Fixed<N>
pub const fn fov(&self) -> Fixed<N>
Fixed quantity wrt field of view, see Self::set_fov().
Sourcepub fn set_fov(&mut self, fov: impl Into<Fixed<N>>)
pub fn set_fov(&mut self, fov: impl Into<Fixed<N>>)
Sets fixed quantity wrt field of view.
Default is fixed vertical field of view of π/4.
use nalgebra::Point2;
use trackball::Scope;
// Current screen size.
let max = Point2::new(800, 600);
// Default scope with fixed vertical field of view of π/4:
//
// * Increasing width increases horizontal field of view (more can be seen).
// * Increasing height scales scope zooming in as vertical field of view is fixed.
let mut scope = Scope::default();
// Unfix vertical field of view by fixing current unit per pixel on focus plane at distance
// from eye of one, that is effectively `upp` divided by `zat` to make it scale-independant:
//
// * Increasing width increases horizontal field of view (more can be seen).
// * Increasing height increases vertical field of view (more can be seen).
scope.set_fov(scope.fov().to_upp(&max.cast::<f32>()));Sourcepub fn clip_planes(&self, zat: N) -> (N, N)
pub fn clip_planes(&self, zat: N) -> (N, N)
Clip plane distances from eye regardless of Self::scale() wrt to distance between eye
and target.
Default is (1e-1, 1e+3) measured from eye.
Sourcepub const fn set_clip_planes(&mut self, znear: N, zfar: N)
pub const fn set_clip_planes(&mut self, znear: N, zfar: N)
Sets clip plane distances from target or eye whether Self::scale().
Default is (1e-1, 1e+3) measured from eye.
Sourcepub const fn scale(&self) -> bool
pub const fn scale(&self) -> bool
Object inspection mode.
Scales clip plane distances by measuring from target instead of eye. Default is false.
Sourcepub const fn set_scale(&mut self, oim: bool)
pub const fn set_scale(&mut self, oim: bool)
Sets object inspection mode.
Scales clip plane distances by measuring from target instead of eye. Default is false.
Sourcepub const fn ortho(&self) -> bool
pub const fn ortho(&self) -> bool
Orthographic projection mode.
Computes scale-identical orthographic instead of perspective projection. Default is false.
Sourcepub const fn set_ortho(&mut self, opm: bool)
pub const fn set_ortho(&mut self, opm: bool)
Sets orthographic projection mode.
Computes scale-identical orthographic instead of perspective projection. Default is false.
Sourcepub fn projection_and_upp(
&self,
zat: N,
max: &OPoint<N, Const<2>>,
) -> (Matrix<N, Const<4>, Const<4>, ArrayStorage<N, 4, 4>>, N)
pub fn projection_and_upp( &self, zat: N, max: &OPoint<N, Const<2>>, ) -> (Matrix<N, Const<4>, Const<4>, ArrayStorage<N, 4, 4>>, N)
Projection transformation and unit per pixel on focus plane wrt distance between eye and target and maximum position in screen space.